@@ -50,7 +50,7 @@ class Command(discord.app_commands.Command):
     async def _invoke_with_namespace(self, interaction, namespace):
         try:
             await super()._invoke_with_namespace(interaction, namespace)
-        except Transformer.InvalidInputForTransformation as error:
+        except (Transformer.InvalidInputForTransformation, discord.app_commands.errors.TransformerError) as error:
             await interaction.response.send_message(
                 "Your input didn't quite match what I was expecting: {}".format(error.args[0]),
                 ephemeral=True
@@ -141,6 +141,10 @@ class RegexType(Transformer):
             ))
         return match
 
+def ChannelUnionType(*channelTypes):
+    return discord.app_commands.transformers.BaseChannelTransformer(*channelTypes)
+
+
 UserOrMemberType = Union[discord.User, discord.Member]
 
 # Pattern 1) Args return a command parameter. Our Command Type manually updates self._params etc with meaningful info
