@@ -903,6 +903,21 @@ async def check_future_dispatch(self):
 async def heartbeat(client):
     await client.controller.heartbeat()
 
+@APIEssentials.subscribe('ready', once=True)
+async def enable_sentry_tracing(self, event):
+    sentry_conf = await self.controller.config_get('__global__', 'sentryio', default={'dsn': None})
+    if sentry_conf['dsn'] is not None:
+        try:
+            import sentry_sdk
+        except ImportError:
+            logger.error("Cannot enable sentry tracing, sentry_sdk is not installed in the current environment")
+            raise
+        sentry_sdk.init(
+            **sentry_conf
+        )
+        logger.info("Sentry.io error tracing enabled")
+
+
 @APIEssentials.subscribe('ready', once=True)
 async def first_ready(self, event):
     try:
